@@ -32,7 +32,7 @@ from typing import (
 import pytest
 from dirty_equals import HasRepr, IsStr
 from pydantic_core import CoreSchema, core_schema
-from typing_extensions import Annotated, Literal, OrderedDict, TypeVarTuple, Unpack, get_args
+from typing_extensions import Annotated, Literal, OrderedDict, ParamSpec, TypeVarTuple, Unpack, get_args
 
 from pydantic import (
     BaseModel,
@@ -2022,6 +2022,27 @@ def test_generic_subclass_with_extra_type_requires_all_params():
             ...
 
 
+def test_generic_subclass_with_extra_type_with_hint_message():
+    E = TypeVar('E', bound=BaseModel)
+    D = TypeVar('D')
+
+    class BaseGenericClass(Generic[E, D], BaseModel):
+        uid: str
+        name: str
+
+    with pytest.raises(
+        TypeError,
+        match=re.escape(
+            'All parameters must be present on typing.Generic; you should inherit from typing.Generic[~E, ~D].'
+            ' Note: `typing.Generic` must go last:'
+            ' `class ChildGenericClass(BaseGenericClass, typing.Generic[~E, ~D]): ...`'
+        ),
+    ):
+
+        class ChildGenericClass(BaseGenericClass[E, Dict[str, Any]]):
+            ...
+
+
 def test_multi_inheritance_generic_binding():
     T = TypeVar('T')
 
@@ -2534,3 +2555,61 @@ def test_generic_none():
 
     assert Container[type(None)](value=None).value is None
     assert Container[None](value=None).value is None
+
+
+@pytest.mark.skipif(platform.python_implementation() == 'PyPy', reason='PyPy does not allow ParamSpec in generics')
+def test_paramspec_is_usable():
+    # This used to cause a recursion error due to `P in P is True`
+    # This test doesn't actually test that ParamSpec works properly for validation or anything.
+
+    P = ParamSpec('P')
+
+    class MyGenericParamSpecClass(Generic[P]):
+        def __init__(self, func: Callable[P, None], *args: P.args, **kwargs: P.kwargs) -> None:
+            super().__init__()
+
+    class ParamSpecGenericModel(BaseModel, Generic[P]):
+        my_generic: MyGenericParamSpecClass[P]
+
+        model_config = dict(arbitrary_types_allowed=True)
+
+
+def test_parametrize_with_basemodel():
+    T = TypeVar('T')
+
+    class SimpleGenericModel(BaseModel, Generic[T]):
+        pass
+
+    class Concrete(SimpleGenericModel[BaseModel]):
+        pass
+
+
+def test_no_generic_base():
+    T = TypeVar('T')
+
+    class A(BaseModel, Generic[T]):
+        a: T
+
+    class B(A[T]):
+        b: T
+
+    class C(B[int]):
+        pass
+
+    assert C(a='1', b='2').model_dump() == {'a': 1, 'b': 2}
+    with pytest.raises(ValidationError) as exc_info:
+        C(a='a', b='b')
+    assert exc_info.value.errors(include_url=False) == [
+        {
+            'input': 'a',
+            'loc': ('a',),
+            'msg': 'Input should be a valid integer, unable to parse string as an integer',
+            'type': 'int_parsing',
+        },
+        {
+            'input': 'b',
+            'loc': ('b',),
+            'msg': 'Input should be a valid integer, unable to parse string as an integer',
+            'type': 'int_parsing',
+        },
+    ]
